import{d as s,a7 as m,x as n,V as e,c as l,h as c,f as u,b as f}from"./index-B3YJYWuL.js";import{I as h}from"./ItemsListing-DtfmXfFy.js";import"./VCheckbox-D78puUFe.js";import"./eventbus-DvpacjVb.js";import"./VListItem-cb3L497C.js";import"./VCheckboxBtn-BhpuHI0t.js";import"./VList-BLfQAYp3.js";import"./VCardText-DRLEFzMp.js";import"./VCard-RO2j5jca.js";import"./VMenu-Drg4ytVq.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./ListItem-Dphq6JqC.js";import"./Button-BHspLwId.js";import"./VSpacer-5KTSJ8al.js";/* empty css              */import"./PanelviewItemCompact-CcNCJwVO.js";import"./VAlert-zURyjIT6.js";import"./Container-Bdq9NOs-.js";import"./Toolbar-CHKFZ92z.js";import"./VToolbar-DXSH_jsU.js";import"./VTextField-D-qeMwbB.js";import"./VInfiniteScroll-u7iLmbut.js";import"./layout-DE_eHv51.js";import"./VVirtualScroll-Dq9UVklv.js";const K=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:o}=m(),a=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),p=async function(r){return await f.browse(t.path)};return(r,w)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":p,"sort-keys":["original","name","name_desc"],title:a.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{K as default};
